| Title: | Detection of m7G, m3C and D modification by AlkAnilineSeq |
|---|---|
| Description: | RNAmodR.AlkAnilineSeq implements the detection of m7G, m3C and D modifications on RNA from experimental data generated with the AlkAnilineSeq protocol. The package builds on the core functionality of the RNAmodR package to detect specific patterns of the modifications in high throughput sequencing data. |
| Authors: | Felix G.M. Ernst [aut, cre] (ORCID: <https://orcid.org/0000-0001-5064-0928>), Denis L.J. Lafontaine [ctb, fnd] |
| Maintainer: | Felix G.M. Ernst <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.27.0 |
| Built: | 2026-05-30 06:54:27 UTC |
| Source: | https://github.com/bioc/RNAmodR.AlkAnilineSeq |
7-methyl guanosine (m7G), 3-methyl cytidine (m3C) and Dihydrouridine (D) are commonly found in rRNA and tRNA and can be detected classically by primer extension analysis. However, since the modifications do not interfere with Watson-Crick base pairing, a specific chemical treatment is employed to cause strand breaks specifically at the modified positions.
This classical protocol was converted to a high throughput sequencing method call AlkAnilineSeq and allows modified position be detected by an accumulation of 5'-ends at the N+1 position. Since the identify of the unmodified nucleotide is different for the three modified nucleotides, they modification can be detected at the same time from the same samples.
dataType is c("NormEnd3SequenceData","PileupSequenceData"):
The ModAlkAnilineSeq class uses the
NormEnd5SequenceData
class to store and aggregate data along the transcripts. This includes
normalized values against the whole transcript (normalzed cleavage) and
normalized values against the overlapping reads (stop ratio), which are used
to score for modified positions.
In addition the
PileupSequenceData class is
used as well, to check, whether the base is can be called according to the
expected sequence identity.
Only samples named treated are used for this analysis. Normalization
to untreated samples is currently not used.
ModAlkAnilineSeq(x, annotation = NA, sequences = NA, seqinfo = NA, ...) ModSetAlkAnilineSeq(x, annotation = NA, sequences = NA, seqinfo = NA, ...)ModAlkAnilineSeq(x, annotation = NA, sequences = NA, seqinfo = NA, ...) ModSetAlkAnilineSeq(x, annotation = NA, sequences = NA, seqinfo = NA, ...)
x |
the input which can be of the different types depending on whether
a |
annotation |
annotation data, which must match the information contained
in the BAM files. This is parameter is only required if |
sequences |
sequences matching the target sequences the reads were
mapped onto. This must match the information contained in the BAM files. This
is parameter is only required if |
seqinfo |
An optional |
... |
Optional arguments overwriting default values, which are
|
a ModAlkAnilineSeq or ModSetAlkAnilineSeq object
Felix G.M. Ernst [aut]
- Marchand V, Ayadi L, __Ernst FGM__, Hertler J, Bourguignon-Igel V, Galvanin A, Kotter A, Helm M, __Lafontaine DLJ__, Motorin Y (2018): "AlkAniline-Seq: Profiling of m7 G and m3 C RNA Modifications at Single Nucleotide Resolution." Angewandte Chemie (International ed. in English) 57 (51), P. 16785–16790. DOI: 10.1002/anie.201810946.
library(RNAmodR.Data) library(rtracklayer) annotation <- GFF3File(RNAmodR.Data.example.AAS.gff3()) sequences <- RNAmodR.Data.example.AAS.fasta() files <- list("wt" = c(treated = RNAmodR.Data.example.wt.1()), "Bud23del" = c(treated = RNAmodR.Data.example.bud23.1()), "Trm8del" = c(treated = RNAmodR.Data.example.trm8.1())) # Creating a Modifier object of type ModRiboMethSeq maas <- ModAlkAnilineSeq(files[[1]], annotation = annotation, sequences = sequences) # Creating a ModifierSet object of type ModSetRiboMethSeq msaas <- ModSetAlkAnilineSeq(files, annotation = annotation, sequences = sequences)library(RNAmodR.Data) library(rtracklayer) annotation <- GFF3File(RNAmodR.Data.example.AAS.gff3()) sequences <- RNAmodR.Data.example.AAS.fasta() files <- list("wt" = c(treated = RNAmodR.Data.example.wt.1()), "Bud23del" = c(treated = RNAmodR.Data.example.bud23.1()), "Trm8del" = c(treated = RNAmodR.Data.example.trm8.1())) # Creating a Modifier object of type ModRiboMethSeq maas <- ModAlkAnilineSeq(files[[1]], annotation = annotation, sequences = sequences) # Creating a ModifierSet object of type ModSetRiboMethSeq msaas <- ModSetAlkAnilineSeq(files, annotation = annotation, sequences = sequences)
All of the functions of Modifier and
the ModifierSet classes are
inherited by the ModAlkAnilineSeq and ModSetAlkAnilineSeq
classes.
## S4 replacement method for signature 'ModAlkAnilineSeq' settings(x) <- value ## S4 method for signature 'ModAlkAnilineSeq' aggregateData(x) ## S4 method for signature 'ModAlkAnilineSeq' findMod(x) ## S4 method for signature 'ModAlkAnilineSeq' getDataTrack(x, name, type, ...) ## S4 method for signature 'ModAlkAnilineSeq,GRanges' plotDataByCoord( x, coord, type = c("ends", "scoreNC", "scoreSR"), window.size = 15L, ... ) ## S4 method for signature 'ModAlkAnilineSeq' plotData( x, name, from = 1L, to = 30L, type = c("ends", "scoreNC", "scoreSR"), ... ) ## S4 method for signature 'ModSetAlkAnilineSeq,GRanges' plotDataByCoord( x, coord, type = c("scoreNC", "scoreSR", "ends"), window.size = 15L, ... ) ## S4 method for signature 'ModSetAlkAnilineSeq' plotData( x, name, from = 1L, to = 30L, type = c("scoreNC", "scoreSR", "ends"), ... )## S4 replacement method for signature 'ModAlkAnilineSeq' settings(x) <- value ## S4 method for signature 'ModAlkAnilineSeq' aggregateData(x) ## S4 method for signature 'ModAlkAnilineSeq' findMod(x) ## S4 method for signature 'ModAlkAnilineSeq' getDataTrack(x, name, type, ...) ## S4 method for signature 'ModAlkAnilineSeq,GRanges' plotDataByCoord( x, coord, type = c("ends", "scoreNC", "scoreSR"), window.size = 15L, ... ) ## S4 method for signature 'ModAlkAnilineSeq' plotData( x, name, from = 1L, to = 30L, type = c("ends", "scoreNC", "scoreSR"), ... ) ## S4 method for signature 'ModSetAlkAnilineSeq,GRanges' plotDataByCoord( x, coord, type = c("scoreNC", "scoreSR", "ends"), window.size = 15L, ... ) ## S4 method for signature 'ModSetAlkAnilineSeq' plotData( x, name, from = 1L, to = 30L, type = c("scoreNC", "scoreSR", "ends"), ... )
x |
a |
value |
See |
coord, name, from, to, type, window.size, ...
|
See
|
ModAlkAnilineSeq specific arguments for plotData:
colour - a named character vector of length = 4
for the colours of the individual histograms. The names are expected to be
c("scoreNC","scoreSR")
settings: See
settings.
aggregate: See aggregate.
modify: See modify.
getDataTrack: a list of
DataTrack object.
plotData: See
plotDataByCoord.
plotDataByCoord: See
plotDataByCoord.
data(msaas,package="RNAmodR.AlkAnilineSeq") maas <- msaas[[1]] settings(maas) aggregate(maas) modify(maas) getDataTrack(maas, "1", mainScore(maas))data(msaas,package="RNAmodR.AlkAnilineSeq") maas <- msaas[[1]] settings(maas) aggregate(maas) modify(maas) getDataTrack(maas, "1", mainScore(maas))
'RNAmodR.AlkAnilineSeq' implements the detection of 7-methyl guanosine, 3-methyl cytidine and dihydrouridine from AlkAnilineseq data using the workflow and class the package 'RNAmodR' provides.
Felix G M Ernst [aut], Denis L J Lafontaine [fnd]
Further details are described in the man pages of the
Modifier object and the vignettes.
This contains an example ModifierSet object of type ModSetAlkAnilineSeq
data(msaas)data(msaas)
a ModSetAlkAnilineSeq instance